%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright Ville Vuorinen 2017 - All rights reserved
% FILE: Fire.m 
% PURPOSE: 
% The code utilizes the finite difference method to
% simulate simple compressible flows for premixed
% combustion using c-equation approach (progress 
% variable 
% The code is intended for class room usage only 
% in order to serve as a learning tool. The results 
% should be considered as qualitative only. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Note on variable names
% U,V -> x,y-velocities 
% rho,p, T -> thermodynamics 
% C -> progress variable
% Variables can be visualized as seen in VisualizeResults.m
% or by imagesc(U), imagesc(T) from the command line etc 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear *
clearvars
close all

%%%%%%%%%% Code can simulate 2 cases: mycase = 0/2 %%%%%%%%%%%%%%%%%%%
% 0=periodic BC's
% 2=Bunsen flame  
% Step 1: Choose mycase = 2 to simulate Bunsen flame
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
mycase = 2; 
t=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Step 2
% In the class: 
% many = 0 -> test a single case 
% For the problem 2:
% many = 1 -> test several cases 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
many=0;
HowOftenVisu = 100;

% for multiple case testing
if(many==1)

if(mycase==2)    
Vmax    = 100; % max velocity at center of Bunsen jet
               %AllSlam = [0 0.25 0.5 0.75 1 1.25 1.5]*Vmax; %
               %laminar flame speeds
AllSlam = [0]*Vmax; % laminar flame speeds
                                             % to sweep over 
Allnu   = [0.0001];                   % viscosities to try 
AllMa   = [3];                               % set to 2.5 (Markstein 2.5dx) 
CaseName= ' Bunsen';                         % code will save
                                             % results to file starting
                                             % with CaseName
Amp = 0.0*Vmax; 
saving  = 1;
SimulationTime = 1e-4; % in seconds
parabolic = 0; % 1=parabolic profile, 0=tanh (sharp) profile
else
Vmax    = 100; 
AllSlam = [0.15 0.25 0.5]*Vmax;
Allnu   = [0.00001];
AllMa   = [1]; 
CaseName= ' KernelLaminar';
Amp = 0.0*Vmax; 
saving  = 1;    
SimulationTime = 1e-4; %s
parabolic = 1; 
end



% for single case testing - many=0
else
Vmax    = 100; 
%AllSlam = [0.75]*100;
AllSlam = [0.7]*100;
Allnu   = [0.0001];
AllMa   = [1]; 
CaseName= ' ParabolicFlame';
parabolic = 1; 
Amp = 0.0*Vmax;
Freq= 0.9;
saving  = 1;
SimulationTime = 1e-4; %s
end




for(iii = 1:length(AllSlam))
    for(jjj = 1:length(Allnu))
        for(kkk = 1:length(AllMa))
    
    
SetParameters;
TotalSteps = round(SimulationTime/dt);

CreateFields;

ThermoFluidProperties; 

InitialConditions; 

DerivativeOperators;

InfoStart;

tic

for(t=1:TotalSteps)
    SolveNavierStokes2D;
    VisualizeResultsMy; 
    FilterFields; 
end

toc

if(saving == 1)
SaveAndClearVars;
end
        end
    end
end
