%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FILE: Heat.m 
% PURPOSE: 
% The code utilizes the pseudo-spectral method 
% to solve the incompressible Navier-Stokes equation and 
% temperature advection-diffusion equation. 
% The immersed boundary method can be used to implement 
% solid walls. Also natural convection can be accounted
% for. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear *
clearvars
close all


SetParameters;

CreateFields;

InitializeSimulation; 
DerivativeOperators;

ThermoFluidProperties; 

l=1:Nx/2; r = (Nx/2 + 1):Nx;

rho  = rho1*ones(Ny,Nx);
p   = p1*ones(Ny,Nx);   % setting pressure
T = (p./rho)/R;             % temperature from the equation of state p=rho*R*T

rhoU = rho.*U;              % initializing rhoU and rhoE
rhoE = Cv*rho.*T + 0.5*rho.*(U.^2 + V.^2); 

setBCs;

InfoStart;

tic

Bigd = 5*dx; 
Cs = (1/sqrt(2*pi))*exp(-((X(1,:)-Lx/2).^2)/(2*Bigd^2));  Cs = Cs';
d2dx2(1,:)=0; d2dx2(1,1)=1; 
d2dx2(Nx,:)=0; d2dx2(Nx,Nx)=1; sol = Cs;

for(t=1:10)
    dsoldx = ddx*sol; 
    rhs = (-0.1*dsoldx + 100*Cs);
    rhs(1) = 1; rhs(Nx)=0;
    sol = d2dx2\rhs;
end




figure(1), clf
plot(X(10,:), C(10,:),'-')

figure(2)
dCdx = gradX(C,ddx); setBCs; 
plot(X(10,:), dCdx(10,:),'-')

figure(3)
dCdx2 = gradXX(C,d2dx2); setBCs; 
plot(X(10,:), dCdx2(10,:),'-')


for(t=1:50000)

    
    
end
