if(mycase>0)
%%%%%%% This part refers to lid driven cavity %%%

if(mycase == 1) 
Twall = 293;

U(Ny,:) = - U(Ny-1,:);
U(:,1) = - U(:,2);
U(:,Nx) = - U(:,Nx-1);
U(1,:) = 2*Vmax - U(2,:);

V(Ny,:) = - V(Ny-1,:);
V(:,1) = - V(:,2);
V(:,Nx) = - V(:,Nx-1);
V(1,:) =  - V(2,:);

T(1,:) = 2*Twall - T(2,:);
T(Ny,:) = 2*Twall - T(Ny-1,:);
T(:,1) = 2*Twall - T(:,2);
T(:,Nx) = 2*Twall - T(:,Nx-1);


%%%%%%% This part refers to jet case %%%%%%%%%%%%
elseif(mycase == 2)
Twall = Tb; Tjet = Tu; 

% jet needs 1) coordinate point definition and 2) boundary velocity profile
jet = round(Nx/2-( (Djet/Lx)*Nx/2 ) ):round(Nx/2 + (Djet/Lx)*Nx/2); 
xjet = X(1,jet); % jet x-coordinates from -D/2 ... D/2

% parabolic with sine perturbation
if(parabolic==1)
Vjet = -Vmax*(xjet-xjet(1)).*(xjet-xjet(length(xjet)))/( (Djet^2)/4) ...
       + Amp*(1+sin( 2*pi*Freq*(Vmax/Djet)*t*dt))/2;
% tanh profile
else
B = 12.5; ro = Lx/10;
Vjet = Vmax*0.5*(1-tanh(B*(abs(xjet-Lx/2)./ro - ro./abs(xjet-Lx/2))));
end

% x-velocity BC, 1st set 'no-slip' everywhere ... 
U(Ny,:) = - U(Ny-1,:);
U(:,1) = - U(:,2);
U(:,Nx) = - U(:,Nx-1);
U(1,:) = - U(2,:);
% ... then correct outlet if needed 
if(zeroGradOutletU==1)
U(Ny,:) = U(Ny-1,:);
end
    
% y-velocity BC, 1st set 'no-slip' everywhere + inlet profile ...
V(Ny,:) = - V(Ny-1,:);
V(:,1) = - V(:,2);
V(:,Nx) = - V(:,Nx-1);
V(1,:) =  - V(2,:); V(1 ,jet) = 2*Vjet - V(2,jet);
% ... then correct outlet if needed
if(zeroGradOutletU==1)
V(Ny,:) = V(Ny-1,:);
end

if(zeroGradWallT == 0)
T(1,:) = 2*Twall - T(2,:); T(1,jet) = 2*Tjet - T(2,jet);
T(Ny,:) = 2*Twall - T(Ny-1,:);
T(:,1) = 2*Twall - T(:,2);
T(:,Nx) = 2*Twall - T(:,Nx-1);
else
T(1,:) = T(2,:); T(1,jet) = 2*Tjet - T(2,jet);
T(Ny,:) = T(Ny-1,:);
T(:,1) = T(:,2);
T(:,Nx) = T(:,Nx-1);    
end

if(zeroGradOutletT == 1)
T(Ny,:) = T(Ny-1,:);
end
    


C(1,:) = C(2,:); C(1,jet) = 2*1 - C(2,jet);
C(Ny,:) = C(Ny-1,:);
C(:,1) = C(:,2);
C(:,Nx) = C(:,Nx-1);
rhoC = rho.*C;

%%%%%%% This part refers to flame front propagation %%%%%%%%%%%%
elseif(mycase == 3)
Twall = Tb; Tjet = Tu; 
jet = inx;
xjet = X(1,jet); % jet x-coordinates from -D/2 ... D/2
Vjet = 0;

% x-velocity BC
U(Ny,:) =  U(Ny-1,:);
U(:,1) =  U(:,2);
U(:,Nx) =  U(:,Nx-1);
U(1,:) =  U(2,:);
if(zeroGradOutletU==1)
U(Ny,:) = U(Ny-1,:);
end
    
% y-velocity BC
V(Ny,:) =  V(Ny-1,:);
V(:,1) =  V(:,2);
V(:,Nx) =  V(:,Nx-1);
V(1,:) =   V(2,:);
if(zeroGradOutletU==1)
V(Ny,:) = V(Ny-1,:);
end


T(1,:) = T(2,:); T(1,jet) = 2*Tjet - T(2,jet);
T(Ny,:) = T(Ny-1,:);
T(:,1) = T(:,2);
T(:,Nx) = T(:,Nx-1);    


if(zeroGradOutletT == 1)
T(Ny,:) = T(Ny-1,:);
end
    


C(1,:) = C(2,:); C(1,jet) = 2*1 - C(2,jet);
C(Ny,:) = C(Ny-1,:);
C(:,1) = C(:,2);
C(:,Nx) = C(:,Nx-1);
rhoC = rho.*C;




end    


p(1,:) = p(2,:);
p(Ny,:) = p(Ny-1,:); 
p(:,1) = p(:,2);
p(:,Nx) = p(:,Nx-1);

rho(1,:) = p(1,:)./(T(1,:)*R);
rho(Ny,:) = p(Ny,:)./(T(Ny,:)*R);
rho(:,1) = p(:,1)./(T(:,1)*R);
rho(:,Nx) = p(:,Nx)./(T(:,Nx)*R);



rhoU(1,:) = U(1,:).*rho(1,:);
rhoU(Ny,:) = U(Ny,:).*rho(Ny,:);
rhoU(:,1) = U(:,1).*rho(:,1);
rhoU(:,Nx) = U(:,Nx).*rho(:,Nx);

rhoV(1,:) = V(1,:).*rho(1,:);
rhoV(Ny,:) = V(Ny,:).*rho(Ny,:);
rhoV(:,1) = V(:,1).*rho(:,1);
rhoV(:,Nx) = V(:,Nx).*rho(:,Nx);

rhoE(1,:) = Cv*rho(1,:).*T(1,:) + 0.5*rho(1,:).*(U(1,:).^2 + V(1,: ...
                                                  ).^2);
rhoE(Ny,:) = Cv*rho(Ny,:).*T(Ny,:) + 0.5*rho(Ny,:).*(U(Ny,:).^2 + ...
                                                  V(Ny,:).^2);
rhoE(:,1) = Cv*rho(:,1).*T(:,1) + 0.5*rho(:,1).*(U(:,1).^2 + V(:, ...
                                                  1).^2);
rhoE(:,Nx) = Cv*rho(:,Nx).*T(:,Nx) + 0.5*rho(:,Nx).*(U(:,Nx).^2 + ...
                                                  V(:,Nx).^2);
end